@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ class KAddressBookPart : public KParts::Part
     Q_OBJECT
 
 public:
-    KAddressBookPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
+    explicit KAddressBookPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
     ~KAddressBookPart() override;
 
 public Q_SLOTS:
