@@ -2,7 +2,7 @@
   This file is part of KAddressBook.
   SPDX-FileCopyrightText: 1996-2002 Mirko Boehm <mirko@kde.org>
   SPDX-FileCopyrightText: Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
@@ -71,7 +71,7 @@ PrintingWizard::~PrintingWizard()
 
 void PrintingWizard::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "PrintingWizard");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "PrintingWizard");
     const QSize size = grp.readEntry("Size", QSize(300, 200));
     if (size.isValid()) {
         resize(size);
@@ -80,7 +80,7 @@ void PrintingWizard::readConfig()
 
 void PrintingWizard::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "PrintingWizard");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "PrintingWizard");
     grp.writeEntry("Size", size());
     grp.sync();
 }
